@@ -10,11 +10,11 @@ Data::Text - Class to handle text in an OO way
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -47,6 +47,11 @@ Adds data to the end of the object.
 Contains a simple sanity test for consecutive punctuation.
 I expect I'll improve that.
 
+Successful calls to append() can be daisy chained.
+
+The argument can be a reference to an array of strings, or an object.
+If called with an object, the message as_string() is sent to it for its contents.
+
 =cut
 
 sub append {
@@ -61,6 +66,17 @@ sub append {
 		$params{'text'} = shift;
 	}
 
+	if(ref($params{'text'})) {
+		# Allow the text to be a reference to a list of strings
+		if(ref($params{'text'}) eq 'ARRAY') {
+			foreach my $text(@{$params{'text'}}) {
+				$self = $self->append($text);
+			}
+			return $self;
+		}
+		$params{'text'} = $params{'text'}->as_string();
+	}
+
 	# FIXME: handle ending with an abbreviation
 
 	if($self->{'text'} && ($self->{'text'} =~ /[\.\,]\s*$/)) {
@@ -70,6 +86,8 @@ sub append {
 		}
 	}
 	$self->{'text'} .= $params{'text'};
+
+	return $self;
 }
 
 =head2 as_string
@@ -84,6 +102,18 @@ sub as_string {
 	return $self->{'text'};
 }
 
+=head2	length
+
+Returns the length of the text.
+
+=cut
+
+sub length {
+	my $self = shift;
+
+	return length($self->{'text'});
+}
+
 =head1 AUTHOR
 
 Nigel Horne, C<< <njh at bandsman.co.uk> >>
@@ -130,7 +160,7 @@ L<http://deps.cpantesters.org/?module=Data::Text>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2021 Nigel Horne.
+Copyright 2021 Nigel Horne.
 
 This program is released under the following licence: GPL2
 
